==> nextcloud-21.0.0-7-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/cs.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Nástěnka",
    "Dashboard app" : "Aplikace Nástěnka",
    "Show something" : "Zobrazit něco",
    "Customize" : "Přizpůsobit",
    "Edit widgets" : "Upravit ovládací prvky",
    "Get more widgets from the app store" : "Získejte další ovládací prvky z katalogu aplikací",
    "Change background image" : "Změnit obrázek na pozadí",
    "Weather service" : "Služba předpovědi počasí",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Z důvodu ochrany vašeho soukromí, jsou údaje o počasí pro vás vyžádány vámi využívaným Nextcloud serverem, takže služba, poskytující tato data, neobdrží žádné osobní údaje.",
    "Weather data from Met.no" : "Data o počasí z Met.no",
    "geocoding with Nominatim" : "geokódování s Nominatim",
    "elevation data from OpenTopoData" : "data o nadmořských výškách z OpenTopoData",
    "Weather" : "Počasí",
    "Status" : "Stav",
    "Good morning" : "Dobré ráno",
    "Good morning, {name}" : "Dobré ráno, {name}",
    "Good afternoon" : "Dobré odpoledne",
    "Good afternoon, {name}" : "Dobré odpoledne, {name}",
    "Good evening" : "Dobrý večer",
    "Good evening, {name}" : "Dobrý večer, {name}",
    "Hello" : "Ahoj",
    "Hello, {name}" : "Ahoj, {name}",
    "Pick from Files" : "Vyberte ze souborů",
    "Default images" : "Výchozí obrázky",
    "Plain background" : "Holé pozadí",
    "Insert from {productName}" : "Vložit z {productName}",
    "Good night, {name}" : "Dobrou noc, {name}",
    "Good night" : "Dobrou noc",
    "Pick from files" : "Vybrat ze souborů"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-21.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/cs.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Nástěnka",
    "Dashboard app" : "Aplikace Nástěnka",
    "Show something" : "Zobrazit něco",
    "Customize" : "Přizpůsobit si",
    "Edit widgets" : "Upravit ovládací prvky",
    "Get more widgets from the app store" : "Získejte další ovládací prvky z katalogu aplikací",
    "Change background image" : "Změnit obrázek na pozadí",
    "Weather service" : "Služba předpovědi počasí",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Z důvodu ochrany vašeho soukromí, jsou údaje o počasí pro vás vyžádány vámi využívaným Nextcloud serverem, takže služba, poskytující tato data, neobdrží žádné osobní údaje.",
    "Weather data from Met.no" : "Data o počasí z Met.no",
    "geocoding with Nominatim" : "geokódování s Nominatim",
    "elevation data from OpenTopoData" : "data o nadmořských výškách z OpenTopoData",
    "Weather" : "Počasí",
    "Status" : "Stav",
    "Good morning" : "Dobré ráno",
    "Good morning, {name}" : "Dobré ráno, {name}",
    "Good afternoon" : "Dobré odpoledne",
    "Good afternoon, {name}" : "Dobré odpoledne, {name}",
    "Good evening" : "Dobrý večer",
    "Good evening, {name}" : "Dobrý večer, {name}",
    "Hello" : "Ahoj",
    "Hello, {name}" : "Ahoj, {name}",
    "Pick from Files" : "Vyberte ze souborů",
    "Default images" : "Výchozí obrázky",
    "Plain background" : "Holé pozadí",
    "Insert from {productName}" : "Vložit z {productName}",
    "Good night, {name}" : "Dobrou noc, {name}",
    "Good night" : "Dobrou noc",
    "Pick from files" : "Vybrat ze souborů"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
